==> XPRESStools-0.0.1a0.tar.gz: XPRESStools-0.0.1a0/setup.py <==
"""
XPRESStools
A toolkit for navigating and analyzing gene expression datasets
alias: xpresstools

Copyright (C) 2019  Jordan A. Berg
jordan <dot> berg <at> biochem <dot> utah <dot> edu

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
"""

from setuptools import setup
import re

with open('xpresstools/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

setup(
    name = 'XPRESStools',
    version = version,
    description = 'A toolkit for navigating and analyzing gene expression datasets',
    long_description = open('README.md').read(),
    author = 'Jordan Berg',
    author_email = 'jordan.berg@biochem.utah.edu',
    url = 'https://github.com/XPRESSyourself/XPRESStools',
    packages = ['xpresstools'],
    exclude= ['tests','docs'],
    package_dir = {'xpresstools': 'xpresstools'},
    license = 'GPL-3.0',
    zip_safe = False,
    install_requires=[
          'pandas',
          'numpy',
          'scipy',
          'seaborn',
          'plotly',
          'matplotlib',
          'sklearn',
          'GEOparse',
          'git-lfs'
      ],

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Bio-Informatics'
        ]
)

==> XPRESStools-0.0.3b0.tar.gz: XPRESStools-0.0.3b0/setup.py <==
"""
XPRESStools
A toolkit for navigating and analyzing gene expression datasets
alias: xpresstools

Copyright (C) 2019  Jordan A. Berg
jordan <dot> berg <at> biochem <dot> utah <dot> edu

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
"""

from setuptools import setup
import re

with open('xpresstools/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

setup(
    name = 'XPRESStools',
    version = version,
    description = 'A toolkit for navigating and analyzing gene expression datasets',
    long_description = open('README.md').read(),
    long_description_content_type='text/markdown',
    author = 'Jordan Berg',
    author_email = 'jordan.berg@biochem.utah.edu',
    url = 'https://github.com/XPRESSyourself/XPRESStools',
    packages = ['xpresstools'],
    exclude= ['tests','docs'],
    package_dir = {'xpresstools': 'xpresstools'},
    license = 'GPL-3.0',
    zip_safe = False,
    install_requires=[
          'pandas',
          'numpy',
          'scipy',
          'seaborn',
          'plotly',
          'matplotlib',
          'sklearn',
          'GEOparse',
          'git-lfs'
      ],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Bio-Informatics'
        ]
)
